==> alipay-sdk-python-3.6.332.tar.gz: alipay-sdk-python-3.6.332/alipay/aop/api/response/AlipayEbppInvoiceExpenserulesEmployeeQueryResponse.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppInvoiceExpenserulesEmployeeQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppInvoiceExpenserulesEmployeeQueryResponse, self).__init__()
        self._employee_list = None
        self._page_num = None
        self._page_size = None
        self._total_page_count = None

    @property
    def employee_list(self):
        return self._employee_list

    @employee_list.setter
    def employee_list(self, value):
        if isinstance(value, list):
            self._employee_list = list()
            for i in value:
                self._employee_list.append(i)
    @property
    def page_num(self):
        return self._page_num

    @page_num.setter
    def page_num(self, value):
        self._page_num = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def total_page_count(self):
        return self._total_page_count

    @total_page_count.setter
    def total_page_count(self, value):
        self._total_page_count = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppInvoiceExpenserulesEmployeeQueryResponse, self).parse_response_content(response_content)
        if 'employee_list' in response:
            self.employee_list = response['employee_list']
        if 'page_num' in response:
            self.page_num = response['page_num']
        if 'page_size' in response:
            self.page_size = response['page_size']
        if 'total_page_count' in response:
            self.total_page_count = response['total_page_count']

==> alipay-sdk-python-3.7.708.tar.gz: alipay-sdk-python-3.7.708/alipay/aop/api/response/AlipayEbppInvoiceExpenserulesEmployeeQueryResponse.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppInvoiceExpenserulesEmployeeQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppInvoiceExpenserulesEmployeeQueryResponse, self).__init__()
        self._employee_list = None
        self._employee_open_id_list = None
        self._page_num = None
        self._page_size = None
        self._total_page_count = None

    @property
    def employee_list(self):
        return self._employee_list

    @employee_list.setter
    def employee_list(self, value):
        if isinstance(value, list):
            self._employee_list = list()
            for i in value:
                self._employee_list.append(i)
    @property
    def employee_open_id_list(self):
        return self._employee_open_id_list

    @employee_open_id_list.setter
    def employee_open_id_list(self, value):
        if isinstance(value, list):
            self._employee_open_id_list = list()
            for i in value:
                self._employee_open_id_list.append(i)
    @property
    def page_num(self):
        return self._page_num

    @page_num.setter
    def page_num(self, value):
        self._page_num = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def total_page_count(self):
        return self._total_page_count

    @total_page_count.setter
    def total_page_count(self, value):
        self._total_page_count = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppInvoiceExpenserulesEmployeeQueryResponse, self).parse_response_content(response_content)
        if 'employee_list' in response:
            self.employee_list = response['employee_list']
        if 'employee_open_id_list' in response:
            self.employee_open_id_list = response['employee_open_id_list']
        if 'page_num' in response:
            self.page_num = response['page_num']
        if 'page_size' in response:
            self.page_size = response['page_size']
        if 'total_page_count' in response:
            self.total_page_count = response['total_page_count']
